@@ -1,18 +1,16 @@
 use ndarray::Array2;
-use std::error::Error as StdError;
 
 /// A trait for thermal cameras
 pub trait ThermalCamera {
-    type Error: 'static + StdError;
+    type Error;
 
     /// Get the temperature of the camera.
     ///
-    /// Many cameras have a built-in temperature sensor separate from the camera itself. The
-    /// default implementation of this function returns the mean of the pixels in the image.
+    /// Many cameras have a built-in temperature sensor separate from the camera itself. If a
+    /// device does not have a temperature sensor distinct from the camera, it should return `None`
+    /// (which is what the default implementation does).
     fn temperature(&mut self) -> Option<f32> {
-        let image = self.image().ok()?;
-        let pixel_count = image.len();
-        Some(image.into_iter().sum::<f32>() / pixel_count as f32)
+        None
     }
 
     /// Return a two-dimensional array representing an image from the thermal camera.
